==> haskell-text-rope-0.3-94-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-rope.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-rope
version:              0.3
visibility:           public
id:                   text-rope-0.3-4Sfo2PrHOJfLeQEowoeX8S
key:                  text-rope-0.3-4Sfo2PrHOJfLeQEowoeX8S
license:              BSD-3-Clause
copyright:            2021-2022 Andrew Lelechenko, 2024 Olle Fredriksson
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:
    Andrew Lelechenko <andrew.lelechenko@gmail.com>, Olle Fredriksson <fredriksson.olle@gmail.com>

homepage:             https://github.com/Bodigrim/text-rope
synopsis:             Text lines and ropes
description:
    A wrapper around `Text` for fast line/column navigation and logarithmic concatenation.

category:             Text
abi:                  23723769d3da29ed1d6357bc61503b01
exposed:              True
exposed-modules:
    Data.Text.Lines Data.Text.Mixed.Rope Data.Text.Rope
    Data.Text.Utf16.Lines Data.Text.Utf16.Rope
    Data.Text.Utf16.Rope.Mixed Data.Text.Utf8.Lines Data.Text.Utf8.Rope

hidden-modules:       Data.Text.Lines.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-rope-0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-rope-0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-rope-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-rope
hs-libraries:         HStext-rope-0.3-4Sfo2PrHOJfLeQEowoeX8S
depends:
    base-4.17.2.1 deepseq-1.4.8.0 text-2.0.2
    vector-0.13.2.0-JUxTFkVHiOCDvdzFqkdqvm

haddock-interfaces:   /usr/share/doc/haskell-text-rope/html/text-rope.haddock
haddock-html:         /usr/share/doc/haskell-text-rope/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-rope-0.3-95-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-rope.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-rope
version:              0.3
visibility:           public
id:                   text-rope-0.3-gHeNS7riVoPWHzm7oKT8
key:                  text-rope-0.3-gHeNS7riVoPWHzm7oKT8
license:              BSD-3-Clause
copyright:            2021-2022 Andrew Lelechenko, 2024 Olle Fredriksson
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:
    Andrew Lelechenko <andrew.lelechenko@gmail.com>, Olle Fredriksson <fredriksson.olle@gmail.com>

homepage:             https://github.com/Bodigrim/text-rope
synopsis:             Text lines and ropes
description:
    A wrapper around `Text` for fast line/column navigation and logarithmic concatenation.

category:             Text
abi:                  6ad50d715aaf290fa4fb6e369a72a16c
exposed:              True
exposed-modules:
    Data.Text.Lines Data.Text.Mixed.Rope Data.Text.Rope
    Data.Text.Utf16.Lines Data.Text.Utf16.Rope
    Data.Text.Utf16.Rope.Mixed Data.Text.Utf8.Lines Data.Text.Utf8.Rope

hidden-modules:       Data.Text.Lines.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-rope-0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-rope-0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-rope-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-rope
hs-libraries:         HStext-rope-0.3-gHeNS7riVoPWHzm7oKT8
depends:
    base-4.17.2.1 deepseq-1.4.8.0 text-2.0.2
    vector-0.13.2.0-EKABDCAVgb42yYEtp4rYAX

haddock-interfaces:   /usr/share/doc/haskell-text-rope/html/text-rope.haddock
haddock-html:         /usr/share/doc/haskell-text-rope/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
